@@ -12,7 +12,7 @@ use JSON::PP;
 use Carp 'croak';
 use URI;
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 has user      => ( is => 'rwp' );
 has passwd    => ( is => 'rwp' );
@@ -43,11 +43,11 @@ sub login {
     croak('Must provide "user" and "passwd" values to login() or new()')
         unless ( $self->user and $self->passwd );
 
-    my $form = ( HTML::Form->parse( $self->ua->request(
-        HTTP::Request->new( 'GET', 'https://mail.google.com/tasks/ig' )
-    ) ) )[0];
-
+    my $form = ( HTML::Form->parse(
+        $self->ua->request( HTTP::Request->new( 'GET', 'https://mail.google.com/tasks/ig' ) )
+    ) )[0];
     $form->value( 'Email', $self->user );
+    $form = ( HTML::Form->parse( $self->ua->request( $form->click ) ) )[0];
     $form->value( 'Passwd', $self->passwd );
 
     my $res = $self->ua->request( $form->click );
@@ -146,7 +146,7 @@ Finance::Google::Portfolio - Manipulate Google Finance portfolios a little
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Finance-Google-Portfolio.svg)](https://travis-ci.org/gryphonshafer/Finance-Google-Portfolio)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Finance-Google-Portfolio/badge.png)](https://coveralls.io/r/gryphonshafer/Finance-Google-Portfolio)
